
.. _`Mapping between ValueMap and Values qualifiers`:

Mapping between ValueMap and Values qualifiers
----------------------------------------------

.. index:: pair: CIM Objects; ValueMap

.. automodule:: pywbem._valuemapping

.. autoclass:: pywbem.ValueMapping
    :members:
    :special-members:
    :exclude-members: __init__,__weakref__
    :autosummary:
    :autosummary-inherited-members:
